summaryrefslogtreecommitdiff
path: root/Debian/Debhelper/Buildsystem.pm
diff options
context:
space:
mode:
authorModestas Vainius <modestas@vainius.eu>2009-06-15 16:20:11 +0300
committerModestas Vainius <modestas@vainius.eu>2009-06-17 22:44:31 +0300
commit95f0a0968c30a6737c3f321f305985b3fd33a63e (patch)
treee0bf3bd0f3745792682e7f4397c7f7b84072761b /Debian/Debhelper/Buildsystem.pm
parent49b64c7852744f54250121b1c60544e1f5de70b6 (diff)
Some cosmetic changes in the comments and strings.
* buildsystem -> build system * dh_auto build system -> debhelper build system * plugin -> class * a few rewording changes in the comments. * Enhance python_distutils::DESCRIPTION().
Diffstat (limited to 'Debian/Debhelper/Buildsystem.pm')
-rw-r--r--Debian/Debhelper/Buildsystem.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/Debian/Debhelper/Buildsystem.pm b/Debian/Debhelper/Buildsystem.pm
index d144cf51..da43b7d7 100644
--- a/Debian/Debhelper/Buildsystem.pm
+++ b/Debian/Debhelper/Buildsystem.pm
@@ -1,4 +1,4 @@
# Defines debhelper buildsystem class interface and implementation
# of common functionality.
#
# Copyright: © 2008-2009 Modestas Vainius
@@ -13,7 +13,7 @@ use File::Spec;
use Debian::Debhelper::Dh_Lib;
# Cache DEB_BUILD_GNU_TYPE value. Performance hit of multiple
# invocations is noticable when listing buildsystems.
our $DEB_BUILD_GNU_TYPE = dpkg_architecture_value("DEB_BUILD_GNU_TYPE");
# Build system name. Defaults to the last component of the class
@@ -26,7 +26,7 @@ sub NAME {
return $1;
}
else {
- error("ınvalid buildsystem class name: $class");
+ error("ınvalid build system class name: $class");
}
}
@@ -120,7 +120,7 @@ sub enforce_in_source_building {
# Derived class can call this method in its constructor to enforce
# out of source building even if the user didn't request it. However,
# if $builddir is specified, accept it even if it matches the source
-# directory (soft mode).
+# directory (i.e. out of source is prefered to in source).
sub enforce_out_of_source_building {
my ($this, $builddir) = @_;
if (!defined $this->get_builddir()) {
@@ -347,7 +347,7 @@ sub post_building_step {
# In case of failure, the method may just error() out.
#
# These methods should be overriden by derived classes to
# implement buildsystem specific steps needed to build the
# source. Arbitary number of custom step arguments might be
# passed. Default implementations do nothing.
sub configure {
@@ -1,4 +1,4 @@
-# Defines debhelper buildsystem class interface and implementation
+# Defines debhelper build system class interface and implementation
# of common functionality.
#
@@ -13,7 +13,7 @@ use File::Spec;
use Debian::Debhelper::Dh_Lib;
# Cache DEB_BUILD_GNU_TYPE value. Performance hit of multiple
-# invocations is noticable when listing buildsystems.
+# invocations is noticable when listing build systems.
our $DEB_BUILD_GNU_TYPE = dpkg_architecture_value("DEB_BUILD_GNU_TYPE");
# Build system name. Defaults to the last component of the class
@@ -347,7 +347,7 @@ sub post_building_step {
#
# These methods should be overriden by derived classes to
-# implement buildsystem specific steps needed to build the
+# implement build system specific steps needed to build the
# source. Arbitary number of custom step arguments might be
# passed. Default implementations do nothing.